==> haskell-sandi-0.5-587-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sandi
version:              0.5
visibility:           public
id:                   sandi-0.5-F4grXDkTvvO6Z8fqDWVQEk
key:                  sandi-0.5-F4grXDkTvvO6Z8fqDWVQEk
license:              BSD-3-Clause
maintainer:           Magnus Therning <magnus@therning.org>
synopsis:             Data encoding library
description:          Reasonably fast data encoding library.
category:             Codec, Conduit
abi:                  fdcb29ec859274151045aaf8b553333e
exposed:              True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc

hidden-modules:       Paths_sandi Data.Conduit.Codec.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/sandi-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sandi-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sandi-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sandi
hs-libraries:         HSsandi-0.5-F4grXDkTvvO6Z8fqDWVQEk
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-CdT4yEwurtEjnovKY3L8i exceptions-0.10.7

haddock-interfaces:   /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html:         /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sandi-0.5-588-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sandi
version:              0.5
visibility:           public
id:                   sandi-0.5-7mPUojpBd5GF5KBS9B6ua
key:                  sandi-0.5-7mPUojpBd5GF5KBS9B6ua
license:              BSD-3-Clause
maintainer:           Magnus Therning <magnus@therning.org>
synopsis:             Data encoding library
description:          Reasonably fast data encoding library.
category:             Codec, Conduit
abi:                  77dd2ec2342a1ff2e04d155886036e85
exposed:              True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc

hidden-modules:       Paths_sandi Data.Conduit.Codec.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/sandi-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sandi-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sandi-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sandi
hs-libraries:         HSsandi-0.5-7mPUojpBd5GF5KBS9B6ua
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-9Ano6zkKE8Q3t2Yg7Ibwss exceptions-0.10.7

haddock-interfaces:   /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html:         /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
